@@ -35,8 +35,7 @@ public: // methods
 private: // methods
 
     virtual void print( std::ostream &out ) const override;
-    virtual void expand(const MarsExpandContext& ctx,
-                        std::vector<std::string>& values) const override;
+    virtual void expand(const MarsExpandContext& ctx, std::vector<std::string>& values) const override;
     virtual bool expand(const MarsExpandContext& ctx, std::string& value) const override;
 
     long by_;
